eclipse

package
v3.0.0-...-8217f41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2018 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Eclipse: Chapter 54, Eclipses.

Index

Constants

const (
	None         = iota
	Partial      // for solar eclipses 日偏食
	Annular      // solar 日环食
	AnnularTotal // solar 日全环食
	Penumbral    // for lunar eclipses 半影月食
	Umbral       // lunar 本影月食
	Total        // solar or lunar 全食
)

Eclipse type identifiers returned from Solar and Lunar.

Variables

This section is empty.

Functions

func Lunar

func Lunar(year float64) (eclipseType int, jmax, γ, ρ, σ, mag float64, sdTotal, sdPartial, sdPenumbral unit.Time)

Lunar computes quantities related to lunar eclipses. 月食计算

Argument year is a decimal year specifying a date.

eclipseType will be None, Penumbral, Umbral, or Total. If None, none of the other return values may be meaningful.

jmax is the jde when the center of the eclipse shadow is closest to the Moon center, in a plane through the center of the Moon.

γ is the distance from the eclipse shadow center to the moon center at time jmax.

σ is the radius of the umbral cone in the plane of the Moon.

ρ is the radius of the penumbral cone.

mag is eclipse magnitude.

sd- return values are semidurations of the phases of the eclipse.

γ, σ, and ρ are in units of equatorial Earth radii.

func Solar

func Solar(year float64) (eclipseType int, central bool, jmax, γ, u, p, mag float64)

Solar computes quantities related to solar eclipses. 日食计算

Argument year is a decimal year specifying a date.

eclipseType will be None, Partial, Annular, AnnularTotal, or Total. If None, none of the other return values may be meaningful.

central is true if the center of the eclipse shadow touches the Earth.

jmax is the jde when the center of the eclipse shadow is closest to the Earth center, in a plane through the center of the Earth.

γ is the distance from the eclipse shadow center to the Earth center at time jmax.

u is the radius of the Moon's umbral cone in the plane of the Earth.

p is the radius of the penumbral cone.

mag is eclipse magnitude for partial eclipses. It is not valid for other eclipse types.

γ, u, and p are in units of equatorial Earth radii.

Types

This section is empty.

Jump to