eqtime

package
v3.0.0-...-8217f41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2018 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Eqtime: Chapter 28, Equation of time.

Index

Examples

Constants

This section is empty.

Variables

This section is empty.

Functions

func E

func E(jde float64, e *pp.V87Planet) unit.HourAngle

E computes the "equation of time" for the given JDE. 计算时差

Parameter e must be a planetposition.V87Planet object for Earth obtained with planetposition.LoadPlanet.

Result is equation of time as an hour angle.

Example
// Example 28.a, p. 184
earth, err := pp.LoadPlanet(pp.Earth)
if err != nil {
	fmt.Println(err)
	return
}
j := julian.CalendarGregorianToJD(1992, 10, 13)
eq := eqtime.E(j, earth)
fmt.Printf("%+.1d", sexa.FmtHourAngle(eq))
Output:

+13ᵐ42ˢ.6

func ESmart

func ESmart(jde float64) unit.HourAngle

ESmart computes the "equation of time" for the given JDE. 低精度计算时差

Result is equation of time as an hour angle.

Result is less accurate that E() but the function has the advantage of not requiring the V87Planet object.

Example
// Example 28.b, p. 185
eq := eqtime.ESmart(julian.CalendarGregorianToJD(1992, 10, 13))
fmt.Printf("+%.7f rad\n", eq)
fmt.Printf("%+.1d", sexa.FmtHourAngle(eq))
Output:

+0.0598256 rad
+13ᵐ42ˢ.7

Types

This section is empty.

Jump to