moonmaxdec

package
v3.0.0-...-8217f41 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2018 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Moonmaxdec: Chapter 52, Maximum Declinations of the Moon

Index

Examples

Constants

This section is empty.

Variables

This section is empty.

Functions

func North

func North(y float64) (jde float64, δ unit.Angle)

North computes the maximum northern declination of the Moon near a given date. 北纬最大纬度

Argument year is a decimal year specifying a date near the event.

Returned is the jde of the event nearest the given date and the declination of the Moon at that time.

Example
// Example 52.a, p. 370.
j, δ := moonmaxdec.North(1988.95)
fmt.Printf("JDE = %.4f\n", j)
y, m, d := julian.JDToCalendar(j)
d, f := math.Modf(d)
fmt.Printf("%d %s %d at %0m TD\n", y, time.Month(m), int(d),
	sexa.FmtTime(unit.TimeFromDay(f)))
fmt.Printf("δ = %.4f\n", δ.Deg())
fmt.Printf("%+0d\n", sexa.FmtAngle(δ))
Output:

JDE = 2447518.3346
1988 December 22 at 20ʰ02ᵐ TD
δ = 28.1562
+28°09′22″
Example (C)
// Example 52.c, p. 370.
j, δ := moonmaxdec.North(-3.8)
fmt.Printf("JDE = %.4f\n", j)
y, m, d := julian.JDToCalendar(j)
d, f := math.Modf(d)
fmt.Printf("%d %s %d at %0h TD\n", y, time.Month(m), int(d),
	sexa.FmtTime(unit.TimeFromDay(f)))
fmt.Printf("δ = %.4f\n", δ.Deg())
fmt.Printf("%+0m\n", sexa.FmtAngle(δ))
Output:

JDE = 1719672.1412
-4 March 16 at 15ʰ TD
δ = 28.9739
+28°58′

func South

func South(y float64) (jde float64, δ unit.Angle)

South computes the maximum southern declination of the Moon near a given date. 南纬最大纬度

Argument year is a decimal year specifying a date near the event.

Returned is the jde of the event nearest the given date and the declination of the Moon at that time.

Example
// Example 52.b, p. 370.
j, δ := moonmaxdec.South(2049.3)
fmt.Printf("JDE = %.4f\n", j)
y, m, d := julian.JDToCalendar(j)
d, f := math.Modf(d)
fmt.Printf("%d %s %d at %0h TD\n", y, time.Month(m), int(d),
	sexa.FmtTime(unit.TimeFromDay(f)))
fmt.Printf("δ = %.4f\n", δ.Deg())
fmt.Printf("%+0m\n", sexa.FmtAngle(δ))
Output:

JDE = 2469553.0834
2049 April 21 at 14ʰ TD
δ = -22.1384
-22°08′

Types

This section is empty.

Jump to