Documentation
¶
Overview ¶
Moonposition: Chapter 47, Position of the Moon.
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Parallax ¶
Parallax returns equatorial horizontal parallax of the Moon. 月球赤道地平视差
Argument Δ is distance between centers of the Earth and Moon, in km.
Example ¶
package main
import (
"fmt"
"github.com/mooncaker816/learnmeeus/v3/julian"
"github.com/mooncaker816/learnmeeus/v3/moonposition"
)
func main() {
// Example 47.a, p. 342.
_, _, Δ := moonposition.Position(julian.CalendarGregorianToJD(1992, 4, 12))
π := moonposition.Parallax(Δ)
fmt.Printf("π = %.6f\n", π.Deg())
}
Output: π = 0.991990
func Position ¶
Position returns geocentric location of the Moon. 计算月球地心黄经,黄纬,地月距离
Results are referenced to mean equinox of date and do not include the effect of nutation.
λ Geocentric longitude. β Geocentric latidude. Δ Distance between centers of the Earth and Moon, in km.
Example ¶
package main
import (
"fmt"
"github.com/mooncaker816/learnmeeus/v3/julian"
"github.com/mooncaker816/learnmeeus/v3/moonposition"
)
func main() {
// Example 47.a, p. 342.
λ, β, Δ := moonposition.Position(julian.CalendarGregorianToJD(1992, 4, 12))
fmt.Printf("λ = %.6f\n", λ.Deg())
fmt.Printf("β = %.6f\n", β.Deg())
fmt.Printf("Δ = %.1f\n", Δ)
}
Output: λ = 133.162655 β = -3.229126 Δ = 368409.7
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.