Documentation
¶
Overview ¶
Sidereal: Chapter 12, Sidereal Time at Greenwich.
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Apparent ¶
Apparent returns apparent sidereal time at Greenwich for the given JD.
Apparent is mean plus the nutation in right ascension.
The result is in the range [0,86400). 计算格林威治瞬时视恒星时
func Apparent0UT ¶
Apparent0UT returns apparent sidereal time at Greenwich at 0h UT on the given JD.
The result is in the range [0,86400). 计算格林威治0h UT视恒星时
func Mean ¶
Mean returns mean sidereal time at Greenwich for a given JD.
Computation is by IAU 1982 coefficients. The result is in the range [0,86400). 计算格林威治 jd 时刻的瞬时平恒星时,化简结果至一天范围之内
Example (A) ¶
// Example 12.a, p. 88.
jd := 2446895.5
s := sidereal.Mean(jd)
sa := sidereal.Apparent(jd)
fmt.Printf("%.4d\n", sexa.FmtTime(s))
fmt.Printf("%.4d\n", sexa.FmtTime(sa))
Output: 13ʰ10ᵐ46ˢ.3668 13ʰ10ᵐ46ˢ.1351
Example (B) ¶
// Example 12.b, p. 89.
jd := julian.TimeToJD(time.Date(1987, 4, 10, 19, 21, 0, 0, time.UTC))
fmt.Printf("%.4d\n", sexa.FmtTime(sidereal.Mean(jd)))
Output: 8ʰ34ᵐ57ˢ.0896
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.